@@ -9,23 +9,24 @@
 
 // [[Rcpp::export]]
 arma::mat draw_circlemap(arma::mat X,
-                         double kmin,
-                         double kmax,
-                         double phimin,
-                         double phimax,
-                         int iterations) {
+                         double left,
+                         double right,
+                         double bottom,
+                         double top,
+                         int iters) {
   int m = X.n_rows;
   int n = X.n_cols;
-  double K = kmax;
-  double phi = phimin;
-  for (int iter = 0; iter < iterations; iter++) {
+  double K = right;
+  double phi = bottom;
+  for (int iter = 0; iter < iters; iter++) {
     for (int row = 0; row < m; row++) {
       for (int col = 0; col < n; col++) {
+        Rcpp::checkUserInterrupt();
         X(row, col) = X(row, col) + phi + (K / (2 * M_PI)) * sin(2 * M_PI * X(row, col));
-        K = K - ((kmax - kmin) / m);
+        K = K - ((right - left) / m);
       }
-      phi = phi + ((phimax - phimin) / n);
-      K = kmax;
+      phi = phi + ((top - bottom) / n);
+      K = right;
     }
   }
   return X;
